@@ -3,7 +3,7 @@ pub struct DynIter<'a, V> {
     iter: Box<dyn Iterator<Item = V> + 'a>,
 }
 
-impl<'iter, V> Iterator for DynIter<'iter, V> {
+impl<'a, V> Iterator for DynIter<'a, V> {
     type Item = V;
     fn next(&mut self) -> Option<Self::Item> {
         self.iter.next()
@@ -14,10 +14,10 @@ impl<'iter, V> Iterator for DynIter<'iter, V> {
     }
 }
 
-impl<'iter, V> DynIter<'iter, V> {
+impl<'a, V> DynIter<'a, V> {
     pub fn new<I>(iter: I) -> Self
     where
-        I: Iterator<Item = V> + 'iter,
+        I: Iterator<Item = V> + 'a,
     {
         Self {
             iter: Box::new(iter),
