@@ -2,10 +2,7 @@ use futures::stream::Stream;
 use futures::StreamExt;
 use futures::TryStreamExt;
 
-use std::{
-    error::Error,
-    io::{Seek, Write},
-};
+use std::{error::Error, io::Write};
 
 use parquet_format_async_temp::FileMetaData;
 
@@ -25,22 +22,25 @@ pub async fn write_stream<'a, W, S, E>(
     options: WriteOptions,
     created_by: Option<String>,
     key_value_metadata: Option<Vec<KeyValue>>,
-) -> Result<()>
+) -> Result<u64>
 where
-    W: Write + Seek,
+    W: Write,
     S: Stream<Item = std::result::Result<RowGroupIter<'a, E>, E>>,
     E: Error + Send + Sync + 'static,
 {
-    start_file(writer)?;
+    let mut offset = start_file(writer)? as u64;
 
     let row_groups = row_groups
         .map(|row_group| {
-            write_row_group(
+            let (group, size) = write_row_group(
                 writer,
+                offset,
                 schema.columns(),
                 options.compression,
                 row_group.map_err(ParquetError::from_external_error)?,
-            )
+            )?;
+            offset += size;
+            Result::Ok(group)
         })
         .try_collect::<Vec<_>>()
         .await?;
@@ -60,6 +60,8 @@ where
         None,
     );
 
-    end_file(writer, metadata)?;
-    Ok(())
+    let len = end_file(writer, metadata)?;
+    Ok(offset + len)
 }
+
+pub use super::stream_stream::write_stream_stream;
